update_engine: fix english

Fix the english for accuracy regarding DLC.

BUG=chromium:897882
TEST=None

Change-Id: I72ab9ecb7903bb5fb35597222cd7c8b1f4244cfc
Reviewed-on: https://chromium-review.googlesource.com/1351359
Commit-Ready: Xiaochu Liu <xiaochu@chromium.org>
Tested-by: Xiaochu Liu <xiaochu@chromium.org>
Reviewed-by: Amin Hassani <ahassani@chromium.org>
diff --git a/common_service.h b/common_service.h
index dbf897e..f93855d 100644
--- a/common_service.h
+++ b/common_service.h
@@ -53,12 +53,12 @@
                      int32_t in_flags_as_int,
                      bool* out_result);
 
   // Attempts a DLC install operation.
   // |omaha_url|: the URL to query for update.
   // |dlc_ids|: a list of DLC IDs.
   bool AttemptInstall(brillo::ErrorPtr* error,
                       const std::string& omaha_url,
-                      const std::vector<std::string>& dlc_ids);
+                      const std::vector<std::string>& dlc_module_ids);
 
   bool AttemptRollback(brillo::ErrorPtr* error, bool in_powerwash);
@@ -53,12 +53,12 @@
                      bool* out_result);
 
-  // Attempts a DLC install operation.
+  // Attempts a DLC module install operation.
   // |omaha_url|: the URL to query for update.
@@ -53,12 +53,12 @@
   // |omaha_url|: the URL to query for update.
-  // |dlc_ids|: a list of DLC IDs.
+  // |dlc_module_ids|: a list of DLC module IDs.
   bool AttemptInstall(brillo::ErrorPtr* error,
                       const std::string& omaha_url,